#
# Copyright 2020 Xilinx, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

#!/bin/bash
# This script accepts an 8-bit, pre-encoded HEVC file and will send the encoded H.264 output to /tmp/xil_4k_xcode.mp4 at a rate of 20Mbps.

# You may edit this to enable other output bitrates (target-bitrate and max-bitrate).

# You may change the target codec to HEVC by changing:
#     the ama_h264enc plugin to ama_h265enc plugin
#     the h264parse plugin to h265parse plugin

if [ $# -lt 3 ]; then
     echo -e "\e[01;31m"Note : Script did not run. Check the below help on how to run the script and arguments to be given"\e[0m"
     echo "$0 <Device Index> <Input 4K H265/HEVC file> <Number of transcode instances, 1>  <Number of buffers> <fakesink 0/1>"
     echo "Ex: $0 0 ~/videos/Test_4k_60fps.h265 1 2000 1"
     exit 1
fi

#check if the input stream is compatiable with this script
codec_type=`gst-discoverer-1.0 "$2" | grep "video #" | cut -d":" -f2 | awk '{print $1;}'`
echo $codec_type
if [ "$codec_type" != "H.265" ]; then
    echo "This script only supports H.265 input"
    exit -1
fi

width=`gst-discoverer-1.0 -v "$2" | grep "Width:" | grep -o '[0-9]*' | cut -d":" -f2 | head`
echo $width
if [ $width -ne 3840 ]; then
    echo "This script only accepts 4K input"
    exit -1
fi

num_dev=$(ls /dev/ama_transcoder* | wc -l)
if [ $1 -ge $num_dev ]; then
    echo "Device index is not correct, exiting. Possible values are 0 to $((num_dev-1))"
    exit
else
    di=$1
fi

#By default this script generates decoded filesink outputs. Giving 4th argument as 1, script runs for fakesink
if [ -z "$5" ]
then
      echo "No fakesink argument is supplied"
      fakesink=0
else
      echo "fakesink argument is supplied"
      fakesink=$5
fi


if [ -z "$4" ]; then
    echo "num-buffers not passed, setting to 2000"
    num=2000
else
    echo "num-buffers defined"
    num=$4
fi



d=$3


#Check if number of instances is given a value of at least <1>
if [ $3 -lt 1 ]; then
    echo "Num instances are not correct. It should be 1 at least. Run $0 for help"
    exit
fi
sink="fakesink"
pipe=" -v"
for (( c=0; c<$d; c++ ))
do
if [ $fakesink == "0" ]
then
        sink="\"filesink location=/tmp/xil_xcode_4k_$c.mp4 \""
	muxer="! qtmux"
        echo "Script is running for filesink ............"
else
        echo "Script is running for fakesink ............"
	muxer=
fi

pipe="filesrc location=$2
	! parsebin
	! h265parse
	! ama_h265dec device=$di
	! identity eos-after=$((num + 1))
	! ama_h264enc b-frames=2 bitrate=20000000 rate-control=vbr
	! h264parse
	${muxer}
	! fpsdisplaysink video-sink=$sink text-overlay=false sync=false "$pipe

done
pipe="gst-launch-1.0 "$pipe
$pipe
