/*
 * Copyright (c) 2023 Xilinx
 * This package is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.

 * This package is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this package; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
 */

#ifndef __GST_XMA_H__
#define __GST_XMA_H__

#include <gst/video/video-format.h>
#include <xmabuffers.h>
#include <xmalogger.h>

G_BEGIN_DECLS

/* for elements that accept system memory data */
#define GST_XMA_DEVICE_AUTO -1
/* for elements that accept AMA memory data */
#define GST_XMA_DEVICE_UNSPECIFIED -1

#define GST_TYPE_XMA (gst_xma_get_type ())
G_DECLARE_FINAL_TYPE (GstXma, gst_xma, GST, XMA, GObject)

GstXma * gst_xma_get_for_device (guint32 device_id);

struct _GstXma
{
  GObject parent;

  guint32 device;
  XmaHandle xma;
};

XmaLogHandle gst_xma_get_log_handle ();

XmaFormatType gst_xma_get_format (GstVideoFormat fmt, gint32 *flags);
GstVideoFormat gst_xma_from_format (XmaFormatType fmt, gint32 flags);

G_END_DECLS

#endif /* __GST_XMA_H__ */
